@@ -81,11 +81,6 @@ class LogConfigure:
             file_path = file_path.with_suffix(suffix)
         return file_path
 
-    @staticmethod
-    def get_exclude_fields(config: "LogConfigure | None") -> list[str]:
-        exclude_fields: list[str] = environ.get("LOG_EXCLUDE_FIELDS", "").split(",")
-        return config_exclude_fields if config and (config_exclude_fields := config._exclude_fields) else exclude_fields
-
     def _get_file_handler(self, suffix: str, *, encoding: str = "utf-8") -> Handler:
         filename: Path = self.get_filename(suffix)
 
