@@ -1,5 +1,5 @@
 import json
-from collections.abc import Iterable, MutableMapping, MutableSequence
+from collections.abc import Collection, MutableMapping, MutableSequence
 from http import HTTPStatus
 from logging import Logger, getLogger
 from time import time
@@ -11,7 +11,7 @@ from starlette.requests import Request
 from starlette.responses import Response, StreamingResponse
 from starlette.types import ASGIApp
 
-from py_fastapi_logging.config.config import LogConfigure, init_logger
+from py_fastapi_logging.config.config import init_logger
 from py_fastapi_logging.constants import REQUEST_ID_HEADER
 from py_fastapi_logging.middlewares.utils.request_id import generate_request_id
 from py_fastapi_logging.schemas.request import RequestPayload
@@ -25,31 +25,34 @@ _Params: TypeAlias = dict[str, Any] | None
 class LoggingMiddleware(BaseHTTPMiddleware):
     _app_name: str
     _prefix: str | None
-    _config: LogConfigure | None
     _logger: Logger
     _exclude_requests_starting_with: frozenset[str]
+    _filtered_fields: frozenset[str]
     _marker_filtered: str
 
     def __init__(
         self,
         app: ASGIApp,
-        app_name: str,
         dispatch: DispatchFunction | None = None,
+        *,
+        app_name: str,
         prefix: str | None = None,
         logger: Logger | None = None,
-        exclude_requests_starting_with: Iterable[str] | None = None,
+        exclude_requests_starting_with: Collection[str] | None = None,
+        filtered_fields: Collection[str] | None = None,
         marker_filtered: str = "[filtered]",
     ) -> None:
         super(LoggingMiddleware, self).__init__(app, dispatch)
         self._app_name = app_name
         self._prefix = prefix
         self._exclude_requests_starting_with = frozenset(exclude_requests_starting_with or ())
+        self._filtered_fields = frozenset(filtered_fields or ())
         self._marker_filtered = marker_filtered
         if logger is None:
-            self._config = init_logger(app_name=app_name)
+            init_logger(app_name)
             self._logger = getLogger("default")
         else:
-            self._config, self._logger = None, logger
+            self._logger = logger
 
     @staticmethod
     def get_request_id_header(headers: dict[str, str]) -> str | None:
@@ -93,23 +96,25 @@ class LoggingMiddleware(BaseHTTPMiddleware):
         request_id: str = self.get_request_id_header(request_headers) or generate_request_id(prefix=self._prefix)
         set_extra_to_environ("request_id", request_id)
 
-        server: tuple[str, int | None] = request.get("server", ("localhost", 80))
-        host_or_socket, port = server
-
         common_extras: dict[str, str] = {"progname": self._app_name, "request_id": request_id}
-        request_log_payload: RequestPayload = RequestPayload(
-            method=request.method,
-            path=request.url.path,
-            params=dict(request_params) if (request_params := request.query_params) else None,
-            host=f"{host_or_socket}:{port}" if port is not None else host_or_socket,
-            body=request_body,
-        )
 
-        extra_payload: dict[str, Any] = common_extras | {
-            "tags": ["API", "REQUEST"],
-            "payload": self._filter_private_data(request_log_payload),
-        }
-        self._logger.info(f"REQUEST {request.method} {request.url.path}", extra=extra_payload)
+        is_excluded_request = self._is_url_path_in_exclude_list(request)
+        if not is_excluded_request:
+            server: tuple[str, int | None] = request.get("server", ("localhost", 80))
+            host_or_socket, port = server
+            request_log_payload: RequestPayload = RequestPayload(
+                method=request.method,
+                path=request.url.path,
+                params=dict(request_params) if (request_params := request.query_params) else None,
+                host=f"{host_or_socket}:{port}" if port is not None else host_or_socket,
+                body=request_body,
+            )
+
+            extra_payload: dict[str, Any] = common_extras | {
+                "tags": ["API", "REQUEST"],
+                "payload": self._filter_private_data(request_log_payload),
+            }
+            self._logger.info(f"REQUEST {request.method} {request.url.path}", extra=extra_payload)
 
         response: Response
         response_body: bytes
@@ -137,7 +142,7 @@ class LoggingMiddleware(BaseHTTPMiddleware):
                 media_type=response.media_type,
             )
 
-        if response.status_code >= status.HTTP_400_BAD_REQUEST or not self._is_url_path_in_exclude_list(request):
+        if response.status_code >= status.HTTP_400_BAD_REQUEST or not is_excluded_request:
             duration: int = round((time() - start_time) * 1000.0)
             response_log_payload: ResponsePayload = {
                 "status": response.status_code,
@@ -156,48 +161,46 @@ class LoggingMiddleware(BaseHTTPMiddleware):
         return any(request.url.path.startswith(path) for path in self._exclude_requests_starting_with)
 
     def _filter_private_data(self, payload: _Payload) -> _Payload:
-        if not (filtered_fields := LogConfigure.get_exclude_fields(self._config)):
+        if not self._filtered_fields:
             return payload
 
         match payload:
             case {"method": _, "path": _, "host": _, "params": params, "body": str(body)} as value:
                 payload = cast(RequestPayload, value)
-                payload["params"] = self._filter_params(cast(_Params, params), filtered_fields)
-                payload["body"] = self._filter_body(body, filtered_fields)
+                payload["params"] = self._filter_params(cast(_Params, params))
+                payload["body"] = self._filter_body(body)
             case {"status": _, "response_time": _, "response_body": str(body)} as value:
                 payload = cast(ResponsePayload, value)
-                payload["response_body"] = self._filter_body(body, filtered_fields)
+                payload["response_body"] = self._filter_body(body)
 
         return payload
 
-    def _filter_params(self, params: _Params, filtered_fields: list[str]) -> _Params:
-        if not params or not filtered_fields:
+    def _filter_params(self, params: _Params) -> _Params:
+        if not params:
             return params
 
         new_params: dict[str, Any] = params.copy()
         for key in params:
-            if key in filtered_fields:
+            if key in self._filtered_fields:
                 new_params[key] = self._marker_filtered
 
         return new_params
 
-    def _filter_body(self, body: str, filtered_fields: list[str]) -> str:
+    def _filter_body(self, body: str) -> str:
         try:
             request_json: Any = json.loads(body)
-            response_json: Any = self._filter_json_body(request_json, filtered_fields)
+            response_json: Any = self._filter_json_body(request_json)
             return json.dumps(response_json, ensure_ascii=False, separators=(",", ":"))
         except Exception:
             return body
 
-    def _filter_json_body(self, body: Any, filtered_fields: list[str]) -> Any:
+    def _filter_json_body(self, body: Any) -> Any:
         if isinstance(body, MutableMapping):
             return {
-                key: self._filter_json_body(value, filtered_fields)
-                if key not in filtered_fields
-                else self._marker_filtered
+                key: self._filter_json_body(value) if key not in self._filtered_fields else self._marker_filtered
                 for key, value in body.items()
             }
         elif isinstance(body, MutableSequence):
-            return [self._filter_json_body(item, filtered_fields) for item in body]
+            return list(map(self._filter_json_body, body))
         else:
             return body
